Documentation
¶
Index ¶
- Constants
- func Transform[PluginConfig any](ctx context.Context, db plugins.DatabasePool[PluginConfig]) error
- func ValidateFragmentArgumentValues(ctx context.Context, db plugins.DatabasePool[config.PluginConfig], ...)
- func ValidateFragmentArgumentsMissingWith(ctx context.Context, db plugins.DatabasePool[config.PluginConfig], ...)
- type DirectiveArgValueNode
- type DirectiveArgument
- type DocArg
- type DocumentVariables
- type FoundChildValue
- type FragmentSpec
- type RawDirectiveArgument
Constants ¶
const BASE62 = "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
Variables ¶
This section is empty.
Functions ¶
func Transform ¶
Transform is responsible for walking down a document's selection and replaces and fragment spreads with a corresponding fragment references that has the fragment arguments inlined
func ValidateFragmentArgumentValues ¶
func ValidateFragmentArgumentValues( ctx context.Context, db plugins.DatabasePool[config.PluginConfig], errs *plugins.ErrorList, )
func ValidateFragmentArgumentsMissingWith ¶
func ValidateFragmentArgumentsMissingWith( ctx context.Context, db plugins.DatabasePool[config.PluginConfig], errs *plugins.ErrorList, )
Types ¶
type DirectiveArgValueNode ¶
type DirectiveArgValueNode struct {
ID int `json:"id"`
Kind string `json:"kind"`
Raw string `json:"raw"`
Parent *int `json:"parent,omitempty"`
// Name is set when this node is a field of an input object literal
Name string `json:"name,omitempty"`
Children []*DirectiveArgValueNode `json:"children"`
}
DirectiveArgValueNode represents a node in the argument value tree.
type DirectiveArgument ¶
type DirectiveArgument struct {
Name string `json:"name"`
Value *DirectiveArgValueNode `json:"value"` // Full nested structure
}
type DocumentVariables ¶
type FoundChildValue ¶
type RawDirectiveArgument ¶
type RawDirectiveArgument struct {
Name string `json:"name"`
ArgId int `json:"argId"` // if 0, then no valid arg
Raw string `json:"raw"`
}
Define structs for unmarshaling directive arguments.
Click to show internal directories.
Click to hide internal directories.